package org.openxma.dsl.reference.dao;

import org.openxma.dsl.platform.dao.*;
import java.util.Collection;
import org.openxma.dsl.reference.dao.ProductImageDao;
import org.openxma.dsl.reference.model.Product;
import org.openxma.dsl.reference.model.ProductImage;

/**
 *  DAO for product images.
 *  Product images can be found by matching image size.
 *
 * Represents a Data Access Object, as defined in the
 * Core J2EE Pattern Catalog (see http://java.sun.com/blueprints/corej2eepatterns/Patterns/DataAccessObject.html),
 * to abstract and encapsulate all access to entity ProductImageDao.
 * @see ProductImageDao
 */
public interface ProductImageDaoGen extends GenericDao<ProductImage,String>, EntityFactory<ProductImage> {
	/**
	 * Query name constants
	 */
    static final String FIND_ALL_BY_MATCHING_SIZE = "ProductImage.FindAllByMatchingSize";
    /**
	 * Stored procedure name constants
	 */
    /**
     * Factory method to create an empty <code>ProductImage</code> entity with an already assigned identifier.
     * The advantage of this approach, coupled with the fact that we're using the id for equals,
     * is that equality test's are immediately possible and therefore independent from the persistence state
     * of the entity. This in contrast to other solutions where auto generated Keys are used
     * which must wait until the object is persisted or differentiate between transient and managed states.
     * @return a new (transient), empty <code>ProductImage</code> entity with an already assigned identifier.
     */
    ProductImage create();
    /**
     * Factory method to create an empty <code>ProductImage</code> taking all not null attributes.
     *
	 * @param product
	 * @param name
	 * @param fileName
     * @return a new (transient ) <code>ProductImage</code> entity with the given natural identifier and not null attributes set.
     */
    ProductImage create(Product product,String name,String fileName);
    /**
     * Factory method to create and save an empty <code>ProductImage</code> taking all not null attributes.
     *
	 * @param product
	 * @param name
	 * @param fileName
     * @return a new (transient) <code>ProductImage</code> entity with the given natural identifier and not null attributes set.
     */
    ProductImage createAndSave(Product product,String name,String fileName);
    /**
     *
     * @param sizeX
     * @param sizeY
     * @return a collection containing 0 or more persistent ProductImage instances
     */
    Collection<ProductImage> findAllByMatchingSize(Collection<Integer> sizeX,Collection<Integer> sizeY);
}
