package org.openxma.dsl.reference.ui.layouting.server;

import at.spardat.xma.component.ComponentServer;
import at.spardat.xma.session.XMASessionServer;

/**
 * This class implements the generic server part of Layouting.
 * It provides the mapping between typeIds and classnames
 * of all pages in the component.
 *
 */
abstract public class LayoutingGen extends org.openxma.dsl.platform.xma.SpringComponentServer {

    org.openxma.dsl.reference.dto.CustomerView customer1;
    org.openxma.dsl.reference.dto.CustomerView customer2;
    org.openxma.dsl.reference.dto.CustomerView customer3;

    /**
     * Initializes the LayoutingGen. This method is called
     * by the XMA-Runtime.
     *
     * @param session the XMASession, this LayoutingGen belongs to.
     * @param id the unique id of this Layouting.
     */
    public LayoutingGen (XMASessionServer session,short id) {
        super (session,false,id);
    }


    /** the unique typeId for the page LayoutingPage */
    public static final short LayoutingPageClass = 0;
    /** the unique typeId for the page AbsoluteAttachment */
    public static final short AbsoluteAttachmentClass = 1;
    /** the unique typeId for the page RelativeAttachment */
    public static final short RelativeAttachmentClass = 2;
    /** the unique typeId for the page TabulatorAttachment */
    public static final short TabulatorAttachmentClass = 3;
    /** the unique typeId for the page AbsoluteCharAttachment */
    public static final short AbsoluteCharAttachmentClass = 4;
    /** the unique typeId for the page SiblingAttachment */
    public static final short SiblingAttachmentClass = 5;
    /** the unique typeId for the page FieldParts */
    public static final short FieldPartsClass = 6;

    /**
    * Array of the classnames of all pages in
    * this component. The typeIds are used as indices
    * into this array.
     */
    static final String[] modelClasses = {
        "LayoutingPage",
        "AbsoluteAttachment",
        "RelativeAttachment",
        "TabulatorAttachment",
        "AbsoluteCharAttachment",
        "SiblingAttachment",
        "FieldParts"
    };

    /**
    * Gets the short classname for the given typeId of
    * a page in this component. The short classname does
    * not contain the package.
    *
    * @param typeId the unique typeId
    * @return the short classname
     */
    static public String getShortModelClass(short typeId) {
        return modelClasses[typeId];
    }

    /**
    * Gets the full classname for the given typeId of
    * a page in this component.
    *
    * @param typeId the unique typeId
    * @return the full classname
     */
    public String getModelClass(short typeId) {
        return "org.openxma.dsl.reference.ui.layouting.server."+modelClasses[typeId];
    }

    /**
     * returns the customer1
     */
    public org.openxma.dsl.reference.dto.CustomerView getCustomer1() {
        return customer1;
    }

    /**
     * sets the customer1
     */
    public void setCustomer1(org.openxma.dsl.reference.dto.CustomerView customer1) {
        this.customer1 = customer1;
    }

    /**
     * returns the customer2
     */
    public org.openxma.dsl.reference.dto.CustomerView getCustomer2() {
        return customer2;
    }

    /**
     * sets the customer2
     */
    public void setCustomer2(org.openxma.dsl.reference.dto.CustomerView customer2) {
        this.customer2 = customer2;
    }

    /**
     * returns the customer3
     */
    public org.openxma.dsl.reference.dto.CustomerView getCustomer3() {
        return customer3;
    }

    /**
     * sets the customer3
     */
    public void setCustomer3(org.openxma.dsl.reference.dto.CustomerView customer3) {
        this.customer3 = customer3;
    }


}
