package org.openxma.dsl.reference.xma.customeredit.server;

import at.spardat.xma.page.*;
import at.spardat.xma.component.*;
import at.spardat.xma.mdl.*;
import at.spardat.enterprise.util.*;
import at.spardat.xma.mdl.simple.*;

/**
 * This class implements the generic server part of Page1.
 * It implements the models of the page.
 *
 */
public abstract class Page1Gen extends PageServer {
    ISimpleWM customer_firstName;
    ISimpleWM customer_lastName;
    ISimpleWM customer_emailAddress;
    ISimpleWM customer_birthDate;
    ISimpleWM customer_telefonNumber;
    WModel[] widgetModels;


    /**
     * Constructs the Page1Gen.
     * This constructor is called by the runtime. Do not remove!
     *
     * @param component the component this page belongs to
     */
    public Page1Gen(ComponentServer component) {
        super(component, false);
        createModels();
    }

    /**
     * Create and initialize the WidgetModels of the page.
     */
    public void createModels() {
        customer_firstName = new SimpleWM((short) 0, Types.T_STRING, this);
        customer_lastName = new SimpleWM((short) 1, Types.T_STRING, this);
        customer_emailAddress = new SimpleWM((short) 2, Types.T_STRING, this);
        customer_birthDate = new SimpleWM((short) 3, Types.T_DATE, this);
        customer_telefonNumber = new SimpleWM((short) 4, Types.T_STRING, this);

        widgetModels = new WModel[] { (WModel) customer_firstName, (WModel) customer_lastName, (WModel) customer_emailAddress, (WModel) customer_birthDate, (WModel) customer_telefonNumber };
    }

    /**
     * Returns an array of all WidgetModels of this page.
     * @return array of WidgetModels. The returned array is not a copy, therefore
     *          it must not be modified.
     */
    public WModel[] getWModels() {
        return widgetModels;
    }

    /**
     * Replaces the model array generated by guidesigner.
     * May only be called by the runtime. Do not call this method!
     */
    protected void setWModels(WModel[] models) {
        widgetModels=models;
    }

    /**
     * Returns a unique id to identify the type of this Page.
     * @return the typeId
     */
    public short getTypeId() {
        return CustomerEdit.Page1Class;
    }

    /**
     * Returns the component this page belongs to, casted to its actual type.
     * @return The Component. Never null.
     */
    public CustomerEdit getTypedComponent() {
        return (CustomerEdit) getComponent();
    }

    /**
     * Copies values of all attached widget models to attributes of the BusinessData instance variables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void modelToInstanceData() {
        atomicWMToBusinessData(getTypedComponent().getCustomer());
    }

    /**
     * Copies attribute values of the BusinessData instance variables into their attached widget models.
     * This includes simple widget models and tables.
     * Copies them for this page and all contained NotebookPages and statically embedded Pages
     * (embedded via XMAContainer in guidesigner)
     */
    public void instanceDataToModel() {
        businessDataToAtomicWM(getTypedComponent().getCustomer());
    }

    /**
     * Copies values of widget models to attributes of the provided BusinessData objects.
     */
    public void atomicWMToBusinessData(org.openxma.dsl.reference.dto.CustomerView customer) {
        customer.setFirstName(customer_firstName.toString());
        customer.setLastName(customer_lastName.toString());
        customer.setEmailAddress(customer_emailAddress.toString());
        customer.setBirthDate(customer_birthDate.toDate());
        customer.setTelefonNumber(org.openxma.dsl.reference.types.valueobject.TelefonNumber.newOrNull(customer_telefonNumber.toString()));
    }

    /**
     * Copies attribute values of the provided BusinessDatas into widget models.
     */
    public void businessDataToAtomicWM(org.openxma.dsl.reference.dto.CustomerView customer) {
        customer_firstName.set(customer.getFirstName());
        customer_lastName.set(customer.getLastName());
        customer_emailAddress.set(customer.getEmailAddress());
        customer_birthDate.set(customer.getBirthDate());
          customer_telefonNumber.set(org.openxma.dsl.platform.valueobject.ValueObject.valueOrNull(customer.getTelefonNumber()));
    }

    /**
     * Sets the given subpage. The method automatically chooses the
     * correct member variable to set.
     * @param child the subpage to set.
     */
    public void setChild(PageServer child) {
       // no subpages - nothing to do
    }

    /**
     * Removes the given subpage. The method automatically chooses the
     * correct member variable to clear.
     * @param child the subpage to set.
     */
    public void removeChild(PageServer child) {
       // no subpages - nothing to do
    }

}
